Learn R Programming

greeks (version 1.5.1)

Implied_Volatility: Computes the implied volatility for various options via Newton's method

Description

If the value of an option, and other (model)parameters like the risk-free interest rate, the time-to-maturity, and the dividend yield are known, the assumed volatility of the underlying asset, the implied volatility can be inferred. See Hull (2022).

Usage

Implied_Volatility(
  option_price,
  initial_price = 100,
  exercise_price = 100,
  r = 0,
  time_to_maturity = 1,
  dividend_yield = 0,
  model = "Black_Scholes",
  option_type = "European",
  payoff = "call",
  start_volatility = 0.3,
  precision = 1e-06,
  max_iter = 30
)

Value

Named vector containing the values of the Greeks specified in the parameter greek.

Arguments

option_price
  • current price of the option

initial_price
  • initial price of the underlying asset

exercise_price
  • strike price of the option

r
  • risk-free interest rate

time_to_maturity
  • time to maturity in years

dividend_yield
  • dividend yield

model
  • the model to be chosen

option_type

in c("European", "American", "Geometric Asian", "Asian", "Digital") - the type of option to be considered

payoff
  • in c("call", "put")

start_volatility

initial guess

precision

precision of the computation

max_iter

maximal number of iterations of the approximation

References

Hull, J. C. (2022). Options, futures, and other derivatives (11th Edition). Pearson

See Also

BS_Implied_Volatility for the special case option_type = "European" and payoff in c("call", "put")

Examples

Run this code
Implied_Volatility(15, r = 0.05, option_type = "Asian",
payoff = "call")

Run the code above in your browser using DataLab